
# Class: ~~FakeClass~~ _(deprecated)_




URI: [ks:FakeClass](https://w3id.org/linkml/tests/kitchen_sink/FakeClass)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[FakeClass&#124;test_attribute:string%20%3F])](https://yuml.me/diagram/nofunky;dir:TB/class/[FakeClass&#124;test_attribute:string%20%3F])

## Attributes


### Own

 * [➞test_attribute](fakeClass__test_attribute.md)  <sub>0..1</sub>
     * Range: [String](types/String.md)
